@@ -4,6 +4,11 @@
 # KUrl -> QUrl
 # Usage: convert-kurl.pl *.h *.cpp
 
+# VERY IMPORTANT: add add_definitions(-DQT_NO_URL_CAST_FROM_STRING) to your CMakeLists.txt, to catch
+# passing a path to a QUrl via an implicit constructor (and port to QUrl(url) or QUrl::fromLocalFile(path)).
+
+# See https://community.kde.org/Frameworks/Porting_Notes#URL for more advice
+
 use strict;
 use File::Basename;
 use lib dirname($0);
@@ -134,15 +139,17 @@ foreach my $file (@ARGV) {
             my $url = $1;
             s/$url\.directory\(\)/$url\.adjusted(QUrl::RemoveFilename|QUrl::StripTrailingSlash).path()/g;
         }
+        # url.url(KUrl::RemoveTrailingSlash)
+        if (/\.url\([KQ]Url::RemoveTrailingSlash\)/) {
+            s/\.url\([KQ]Url::RemoveTrailingSlash\)/\.adjusted(QUrl::StripTrailingSlash).toString()/g;
+        }
         # url.path(KUrl::RemoveTrailingSlash)
-        if (/(\w+)\.path\(KUrl::RemoveTrailingSlash\)/ && defined $urls{$1}) {
-            my $url = $1;
-            s/$url\.path\(KUrl::RemoveTrailingSlash\)/$url\.adjusted(QUrl::StripTrailingSlash).path()/g;
+        if (/\.path\(KUrl::RemoveTrailingSlash\)/) {
+            s/\.path\(KUrl::RemoveTrailingSlash\)/\.adjusted(QUrl::StripTrailingSlash).path()/g;
         }
         # url.toLocalFile(KUrl::RemoveTrailingSlash)
-        if (/(\w+)\.toLocalFile\(KUrl::RemoveTrailingSlash\)/ && defined $urls{$1}) {
-            my $url = $1;
-            s/$url\.toLocalFile\(KUrl::RemoveTrailingSlash\)/$url\.adjusted(QUrl::StripTrailingSlash).toLocalFile()/g;
+        if (/\.toLocalFile\(KUrl::RemoveTrailingSlash\)/) {
+            s/\.toLocalFile\(KUrl::RemoveTrailingSlash\)/\.adjusted(QUrl::StripTrailingSlash).toLocalFile()/g;
         }
         # url.adjustPath(KUrl::RemoveTrailingSlash)
         if (/(\w+)\.adjustPath\(KUrl::RemoveTrailingSlash\)/ && defined $urls{$1}) {
